#ifndef SYMFONIEOPTIONSDIALOG_H
#define SYMFONIEOPTIONSDIALOG_H

#include <QDialog>

class MainWindow;

namespace Ui {
    class SymfonieOptionsDialog;
}

class SymfonieOptionsDialog : public QDialog {
    Q_OBJECT
public:
    SymfonieOptionsDialog(MainWindow *parent = 0);
    ~SymfonieOptionsDialog();
    bool getOptionIsShowToolbar();
    bool getOptionIsAutoResumePlayback();
    bool getIsContinuouslyPlay();
    int getPlayListFontSizeSbValue();

protected:
    void changeEvent(QEvent *e);

private:
    Ui::SymfonieOptionsDialog *ui;
};

#endif // SYMFONIEOPTIONSDIALOG_H
